#-----------------------------------------------------------------------------
# BringBackLights
# Copyright (c) 2003, David G. Drumright (ockham)
# 10/19/2003

# Designed to let you load new lights without replacing the old.
# Script does a "toggle" action: the first hit stores current set of
# lights in a temp file.
# You then load a new set; then hit this script again to
# bring back the original lights from the temp file.
# The "restore" hit also deletes the temp file.
#-----------------------------------------------------------------------------
import os
import pickle
import poser
scene = poser.Scene()

#-----------------------------------------------------------------------------

if not os.path.exists("lights.tmp"): # No tempfile: Make one.
    Properties={}
    for OneLight in scene.Lights():  # Go through all lights
           OldName = OneLight.InternalName()
           Properties[OldName]=[]
           # First entry is mode (spotlight, local)
           Properties[OldName].append( ("mode",OneLight.LightType()) )
           for OneParm in OneLight.Parameters():
               ParmName = OneParm.Name()
               ParmVal = OneParm.Value()
               Properties[OldName].append( (ParmName,ParmVal) )
    fpTemp=open("lights.tmp","wt") # Open for write
    pickle.dump(Properties,fpTemp) # Put array into file
    fpTemp.close()

else: # Is tempfile, so use it.  Restore lights, then delete tempfile.

    fpTemp=open("lights.tmp","rt") # Open for read
    Properties = pickle.load(fpTemp) # Get array from file
    fpTemp.close()
    # Use the Properties to create new lights.
    for OneLightName in Properties.keys():
        scene.CreateLight() # Make the newest
        NewLight = scene.CurrentActor() # Get the newest
        ParmList = Properties[OneLightName]
        for (ParmName,ParmVal) in ParmList:
            # Give the stored properties to the newest
            if ParmName == "mode":
                NewLight.SetLightType(ParmVal)
            else:
                try:
                    NewLight.Parameter(ParmName).SetValue(ParmVal)
                except:
                    pass

    os.remove("lights.tmp") # Get rid of the tempfile
#-----------------------------------------------------------------------------
